(v1.11.3)=
### 1.11.3 {small}`2025-07-01`

### Bug fixes

- Ensure `axis_nnz` calculates its chunk size/shape correctly with `dask` {smaller}`I Gold` ({pr}`3667`)
- Replace deprecated `np.in1d` with `np.isin` to silence deprecation warnings. {smaller}`E Ferdman` ({pr}`3685`)
- Upperbound {mod}`scipy` to `1.16.0` due to {issue}`statsmodels/statsmodels#9584` {smaller}`I Gold` ({pr}`3695`)

### Documentation

- Fix documentation location for {class}`scanpy.settings` {smaller}`P Angerer` ({pr}`3672`)
